# 0.1.0
* Added ``pyproximal.optimization.sr3.SR3`` solver
* Added ``pyproximal.projection.AffineSetProj`` and
  ``pyproximal.AffineSet`` operators
* Fixed ``pyproximal.Huber`` operator

# 0.0.0
* First official release.

